==> zio-aws-kinesisanalytics_2.13-5.17.123.1-sources.jar: zio/aws/kinesisanalytics/model/KinesisFirehoseOutputUpdate.scala <==
package zio.aws.kinesisanalytics.model
import zio.aws.kinesisanalytics.model.primitives.{RoleARN, ResourceARN}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class KinesisFirehoseOutputUpdate(
    resourceARNUpdate: Option[ResourceARN] = None,
    roleARNUpdate: Option[RoleARN] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseOutputUpdate = {
    import KinesisFirehoseOutputUpdate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseOutputUpdate
      .builder()
      .optionallyWith(
        resourceARNUpdate.map(value =>
          ResourceARN.unwrap(value): java.lang.String
        )
      )(_.resourceARNUpdate)
      .optionallyWith(
        roleARNUpdate.map(value => RoleARN.unwrap(value): java.lang.String)
      )(_.roleARNUpdate)
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisanalytics.model.KinesisFirehoseOutputUpdate.ReadOnly =
    zio.aws.kinesisanalytics.model.KinesisFirehoseOutputUpdate
      .wrap(buildAwsValue())
}
object KinesisFirehoseOutputUpdate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseOutputUpdate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kinesisanalytics.model.KinesisFirehoseOutputUpdate =
      zio.aws.kinesisanalytics.model.KinesisFirehoseOutputUpdate(
        resourceARNUpdate.map(value => value),
        roleARNUpdate.map(value => value)
      )
    def resourceARNUpdate: Option[ResourceARN]
    def roleARNUpdate: Option[RoleARN]
    def getResourceARNUpdate: ZIO[Any, AwsError, ResourceARN] =
      AwsError.unwrapOptionField("resourceARNUpdate", resourceARNUpdate)
    def getRoleARNUpdate: ZIO[Any, AwsError, RoleARN] =
      AwsError.unwrapOptionField("roleARNUpdate", roleARNUpdate)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseOutputUpdate
  ) extends zio.aws.kinesisanalytics.model.KinesisFirehoseOutputUpdate.ReadOnly {
    override val resourceARNUpdate: Option[ResourceARN] = scala
      .Option(impl.resourceARNUpdate())
      .map(value =>
        zio.aws.kinesisanalytics.model.primitives.ResourceARN(value)
      )
    override val roleARNUpdate: Option[RoleARN] = scala
      .Option(impl.roleARNUpdate())
      .map(value => zio.aws.kinesisanalytics.model.primitives.RoleARN(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseOutputUpdate
  ): zio.aws.kinesisanalytics.model.KinesisFirehoseOutputUpdate.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-kinesisanalytics_2.13-7.21.15.7-sources.jar: zio/aws/kinesisanalytics/model/KinesisFirehoseOutputUpdate.scala <==
package zio.aws.kinesisanalytics.model
import zio.aws.kinesisanalytics.model.primitives.{RoleARN, ResourceARN}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class KinesisFirehoseOutputUpdate(
    resourceARNUpdate: Optional[ResourceARN] = Optional.Absent,
    roleARNUpdate: Optional[RoleARN] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseOutputUpdate = {
    import KinesisFirehoseOutputUpdate.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseOutputUpdate
      .builder()
      .optionallyWith(
        resourceARNUpdate.map(value =>
          ResourceARN.unwrap(value): java.lang.String
        )
      )(_.resourceARNUpdate)
      .optionallyWith(
        roleARNUpdate.map(value => RoleARN.unwrap(value): java.lang.String)
      )(_.roleARNUpdate)
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisanalytics.model.KinesisFirehoseOutputUpdate.ReadOnly =
    zio.aws.kinesisanalytics.model.KinesisFirehoseOutputUpdate
      .wrap(buildAwsValue())
}
object KinesisFirehoseOutputUpdate {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseOutputUpdate
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kinesisanalytics.model.KinesisFirehoseOutputUpdate =
      zio.aws.kinesisanalytics.model.KinesisFirehoseOutputUpdate(
        resourceARNUpdate.map(value => value),
        roleARNUpdate.map(value => value)
      )
    def resourceARNUpdate: Optional[ResourceARN]
    def roleARNUpdate: Optional[RoleARN]
    def getResourceARNUpdate: ZIO[Any, AwsError, ResourceARN] =
      AwsError.unwrapOptionField("resourceARNUpdate", resourceARNUpdate)
    def getRoleARNUpdate: ZIO[Any, AwsError, RoleARN] =
      AwsError.unwrapOptionField("roleARNUpdate", roleARNUpdate)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseOutputUpdate
  ) extends zio.aws.kinesisanalytics.model.KinesisFirehoseOutputUpdate.ReadOnly {
    override val resourceARNUpdate: Optional[ResourceARN] =
      zio.aws.core.internal
        .optionalFromNullable(impl.resourceARNUpdate())
        .map(value =>
          zio.aws.kinesisanalytics.model.primitives.ResourceARN(value)
        )
    override val roleARNUpdate: Optional[RoleARN] = zio.aws.core.internal
      .optionalFromNullable(impl.roleARNUpdate())
      .map(value => zio.aws.kinesisanalytics.model.primitives.RoleARN(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.KinesisFirehoseOutputUpdate
  ): zio.aws.kinesisanalytics.model.KinesisFirehoseOutputUpdate.ReadOnly =
    new Wrapper(impl)
}
